require "libs.TEsound"

function love.load()
	debug = {}
	
	-- Load screen types
	screens = {}
	screens.title		= require "screens.title"
	screens.gameplay	= require "screens.gameplay"
	screens.results		= require "screens.results"

	-- Initialize layers
	layers = {
		each = function(self, fn, ...)
			for k, v in ipairs(self) do
				if v[fn] then
					v[fn](v, unpack {...})
				end
			end
		end,
		screens.title(nil)
	}
	
	TEsound.play("assets/jb.mp3")
	
	layers:each("load")
end

function love.update(dt)
	for k, v in ipairs(layers) do
		if v.next.screen then
			local n = #layers
			table.remove(layers, n)
			layers[n] = screens[v.next.screen](v.next.data)
			layers[n]:load()
		end
	end

	layers:each("update", dt)

	TEsound.cleanup()
end

function love.draw()
	layers:each("draw")

	-- Display debug info
	local i = 0
	for k, v in pairs(debug) do
		local r = type(v) == "table" and "" or v
		if type(v) == "table" then
			for _, v2 in ipairs(v) do
				r = r .. " " .. v2
			end
		end
		love.graphics.print(k .. ": " .. r, 0, i * 15)
		i = i + 1
	end
end

function love.keypressed(k, unicode)
	layers:each("keypressed", k, unicode)
end

function love.keyreleased(k, unicode)
	layers:each("keyreleased", k, unicode)
end

function love.mousepressed(x, y, button)
	layers:each("mousepressed", x, y, button)
end

function love.mousereleased(x, y, button)
	layers:each("mousereleased", x, y, button)
end

function love.joystickpressed(joystick, button)
	layers:each("joystickpressed", joystick, button)
end

function love.joystickreleased(joystick, button)
	layers:each("joystickreleased", joystick, button)
end

function love.quit()
	layers:each("quit")
end
