require "libs.screen"

local function load(self)
	self.time = 0
	self.score = 0
	
	self.background = love.graphics.newImage("assets/background.jpg")
	
	self.player = {
		gun		= love.graphics.newImage("assets/gun.png"),
		bullet	= {
			img = love.graphics.newImage("assets/bullet.png"),
			draw = false,
		},
		x = 10,
		y = 0,
	}
	
	self.bulbs = {
		obj = {},
		img = {
			love.graphics.newImage("assets/bulb_1.png"),
			love.graphics.newImage("assets/bulb_2.png"),
			love.graphics.newImage("assets/bulb_3.png"),
			love.graphics.newImage("assets/bulb_4.png"),
		},
	}
end

local function update(self, dt)
	self.time = self.time + dt
	
	if self.time >= 1 then
		self.time = self.time - 1
		
		self.bulbs.obj[math.random(999999)] = {
			img = self.bulbs.img[math.random(4)],
			x = 800,
			y = 64 * math.random(9) - 64,
		}
	end
	
	if self.player.y < 0 then
		self.player.y = 0
	end
	
	if self.player.y > 512 then
		self.player.y = 512
	end
	
	if not self.player.bullet.draw then
		self.player.bullet.x = 138
		self.player.bullet.y = self.player.y + 6
	else
		self.player.bullet.x = self.player.bullet.x + (1024 * dt)
	end
	
	if self.player.bullet.x > 800 then
		self.player.bullet.draw = false
	end
	
	for k,v in pairs(self.bulbs.obj) do
		v.x = v.x - (256 * dt)
		
		if self.player.x + 128 >= v.x then
			self.next.screen = "results"
			self.next.data = {
				score = self.score,
			}
		end
		
		if	self.player.bullet.draw == true and self.player.bullet.y - 6 == v.y then
			if self.player.bullet.x + 32 >= v.x and self.player.bullet.x + 32 <= v.x + 64 then
				self.bulbs.obj[k] = nil
				self.player.bullet.draw = false
				self.score = self.score + 100
			end
		end
	end
end

local function draw(self)
	love.graphics.draw(self.background, 0, 0)
	love.graphics.draw(self.player.gun, self.player.x, self.player.y)
	
	if self.player.bullet.draw then
		love.graphics.draw(self.player.bullet.img, self.player.bullet.x, self.player.bullet.y)
	end
	
	for k,v in pairs(self.bulbs.obj) do
		love.graphics.draw(v.img, v.x, v.y)
	end
	
	love.graphics.print(self.score, 700, 0)
end

local function keypressed(self, k, unicode)
	if k == "up" or k == "w" then
		self.player.y = self.player.y - 64
	end
	
	if k == "down" or k == "s" then
		self.player.y = self.player.y + 64
	end
	
	if k == "return" or k == " " then
		if not self.player.bullet.draw then
			TEsound.play("assets/gun.mp3")
			self.player.bullet.draw = true
		end
	end
end

return function(data)
	return Screen {
		name			= "Gameplay",
		load			= load,
		update			= update,
		draw			= draw,
		keypressed		= keypressed,
		data			= data
	}
end
